# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeploymentSetArgs', 'DeploymentSet']

@pulumi.input_type
class DeploymentSetArgs:
    def __init__(__self__, *,
                 deployment_set_name: pulumi.Input[builtins.str],
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a DeploymentSet resource.
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        pulumi.set(__self__, "deployment_set_name", deployment_set_name)
        if deployment_set_group_number is not None:
            pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if group_count is not None:
            pulumi.set(__self__, "group_count", group_count)
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> pulumi.Input[builtins.str]:
        """
        部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        """
        return pulumi.get(self, "deployment_set_name")

    @deployment_set_name.setter
    def deployment_set_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "deployment_set_name", value)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组的序号，取值范围：1～7。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @deployment_set_group_number.setter
    def deployment_set_group_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "deployment_set_group_number", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "granularity", value)

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        """
        return pulumi.get(self, "group_count")

    @group_count.setter
    def group_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_count", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        部署集内的ECS实例ID列表。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "strategy", value)


@pulumi.input_type
class _DeploymentSetState:
    def __init__(__self__, *,
                 capacities: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentSetCapacityArgs']]]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
                 deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_amount: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DeploymentSet resources.
        :param pulumi.Input[builtins.str] created_at: 部署集的创建时间。
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] deployment_set_id: 部署集ID。
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[builtins.int] instance_amount: 部署集内的ECS实例数量。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        if capacities is not None:
            pulumi.set(__self__, "capacities", capacities)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if deployment_set_group_number is not None:
            pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if deployment_set_id is not None:
            pulumi.set(__self__, "deployment_set_id", deployment_set_id)
        if deployment_set_name is not None:
            pulumi.set(__self__, "deployment_set_name", deployment_set_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if group_count is not None:
            pulumi.set(__self__, "group_count", group_count)
        if instance_amount is not None:
            pulumi.set(__self__, "instance_amount", instance_amount)
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter
    def capacities(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentSetCapacityArgs']]]]:
        return pulumi.get(self, "capacities")

    @capacities.setter
    def capacities(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentSetCapacityArgs']]]]):
        pulumi.set(self, "capacities", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集的创建时间。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组的序号，取值范围：1～7。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @deployment_set_group_number.setter
    def deployment_set_group_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "deployment_set_group_number", value)

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @deployment_set_id.setter
    def deployment_set_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deployment_set_id", value)

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        """
        return pulumi.get(self, "deployment_set_name")

    @deployment_set_name.setter
    def deployment_set_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deployment_set_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "granularity", value)

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        """
        return pulumi.get(self, "group_count")

    @group_count.setter
    def group_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_count", value)

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        部署集内的ECS实例数量。
        """
        return pulumi.get(self, "instance_amount")

    @instance_amount.setter
    def instance_amount(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "instance_amount", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        部署集内的ECS实例ID列表。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "strategy", value)


@pulumi.type_token("bytepluscc:ecs/deploymentSet:DeploymentSet")
class DeploymentSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        部署集是在底层硬件维度上控制实例分散部署的策略，可以实现物理层级的安全隔离。您可以通过创建部署集，使实例分散部署在不同的底层硬件上，用于保障业务的底层容灾能力及高可用性。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        ecs_deployment_set_demo = bytepluscc.ecs.DeploymentSet("EcsDeploymentSetDemo",
            description="this is a test DeploymentSet",
            deployment_set_name="test-deployment-set",
            granularity="host",
            instance_ids=["i-yedvixxxxxva4izkjtl"],
            deployment_set_group_number=1,
            strategy="Availability")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/deploymentSet:DeploymentSet example "deployment_set_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        部署集是在底层硬件维度上控制实例分散部署的策略，可以实现物理层级的安全隔离。您可以通过创建部署集，使实例分散部署在不同的底层硬件上，用于保障业务的底层容灾能力及高可用性。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        ecs_deployment_set_demo = bytepluscc.ecs.DeploymentSet("EcsDeploymentSetDemo",
            description="this is a test DeploymentSet",
            deployment_set_name="test-deployment-set",
            granularity="host",
            instance_ids=["i-yedvixxxxxva4izkjtl"],
            deployment_set_group_number=1,
            strategy="Availability")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/deploymentSet:DeploymentSet example "deployment_set_id"
        ```

        :param str resource_name: The name of the resource.
        :param DeploymentSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
                 deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 granularity: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentSetArgs.__new__(DeploymentSetArgs)

            __props__.__dict__["deployment_set_group_number"] = deployment_set_group_number
            if deployment_set_name is None and not opts.urn:
                raise TypeError("Missing required property 'deployment_set_name'")
            __props__.__dict__["deployment_set_name"] = deployment_set_name
            __props__.__dict__["description"] = description
            __props__.__dict__["granularity"] = granularity
            __props__.__dict__["group_count"] = group_count
            __props__.__dict__["instance_ids"] = instance_ids
            __props__.__dict__["strategy"] = strategy
            __props__.__dict__["capacities"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["deployment_set_id"] = None
            __props__.__dict__["instance_amount"] = None
        super(DeploymentSet, __self__).__init__(
            'bytepluscc:ecs/deploymentSet:DeploymentSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacities: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DeploymentSetCapacityArgs', 'DeploymentSetCapacityArgsDict']]]]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            deployment_set_group_number: Optional[pulumi.Input[builtins.int]] = None,
            deployment_set_id: Optional[pulumi.Input[builtins.str]] = None,
            deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            granularity: Optional[pulumi.Input[builtins.str]] = None,
            group_count: Optional[pulumi.Input[builtins.int]] = None,
            instance_amount: Optional[pulumi.Input[builtins.int]] = None,
            instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            strategy: Optional[pulumi.Input[builtins.str]] = None) -> 'DeploymentSet':
        """
        Get an existing DeploymentSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: 部署集的创建时间。
        :param pulumi.Input[builtins.int] deployment_set_group_number: 部署集组的序号，取值范围：1～7。
        :param pulumi.Input[builtins.str] deployment_set_id: 部署集ID。
        :param pulumi.Input[builtins.str] deployment_set_name: 部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        :param pulumi.Input[builtins.str] description: 部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] granularity: 部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        :param pulumi.Input[builtins.int] group_count: 部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        :param pulumi.Input[builtins.int] instance_amount: 部署集内的ECS实例数量。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 部署集内的ECS实例ID列表。
        :param pulumi.Input[builtins.str] strategy: 部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeploymentSetState.__new__(_DeploymentSetState)

        __props__.__dict__["capacities"] = capacities
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["deployment_set_group_number"] = deployment_set_group_number
        __props__.__dict__["deployment_set_id"] = deployment_set_id
        __props__.__dict__["deployment_set_name"] = deployment_set_name
        __props__.__dict__["description"] = description
        __props__.__dict__["granularity"] = granularity
        __props__.__dict__["group_count"] = group_count
        __props__.__dict__["instance_amount"] = instance_amount
        __props__.__dict__["instance_ids"] = instance_ids
        __props__.__dict__["strategy"] = strategy
        return DeploymentSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def capacities(self) -> pulumi.Output[Sequence['outputs.DeploymentSetCapacity']]:
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        部署集的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> pulumi.Output[builtins.int]:
        """
        部署集组的序号，取值范围：1～7。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> pulumi.Output[builtins.str]:
        """
        部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> pulumi.Output[builtins.str]:
        """
        部署集名称。不能以数字、中划线、下划线开头。只能包含中文、字母、数字、下划线和中划线。长度限制为1～128个字符。
        """
        return pulumi.get(self, "deployment_set_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        部署集的描述信息。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”。长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def granularity(self) -> pulumi.Output[builtins.str]:
        """
        部署粒度，取值：host：物理机。rack：机架。switch：交换机。
        """
        return pulumi.get(self, "granularity")

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> pulumi.Output[builtins.int]:
        """
        部署集组数量。为部署集组高可用策略设置分组数量。取值范围：1～7。默认值：7。
        """
        return pulumi.get(self, "group_count")

    @property
    @pulumi.getter(name="instanceAmount")
    def instance_amount(self) -> pulumi.Output[builtins.int]:
        """
        部署集内的ECS实例数量。
        """
        return pulumi.get(self, "instance_amount")

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        部署集内的ECS实例ID列表。
        """
        return pulumi.get(self, "instance_ids")

    @property
    @pulumi.getter
    def strategy(self) -> pulumi.Output[builtins.str]:
        """
        部署策略，取值：Availability（默认）：高可用策略。AvailabilityGroup：部署集组高可用策略。
        """
        return pulumi.get(self, "strategy")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTrafficMirrorFilterResult',
    'AwaitableGetTrafficMirrorFilterResult',
    'get_traffic_mirror_filter',
    'get_traffic_mirror_filter_output',
]

@pulumi.output_type
class GetTrafficMirrorFilterResult:
    """
    A collection of values returned by getTrafficMirrorFilter.
    """
    def __init__(__self__, created_time=None, description=None, egress_filter_rules=None, id=None, ingress_filter_rules=None, project_name=None, status=None, tags=None, traffic_mirror_filter_id=None, traffic_mirror_filter_name=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if egress_filter_rules and not isinstance(egress_filter_rules, list):
            raise TypeError("Expected argument 'egress_filter_rules' to be a list")
        pulumi.set(__self__, "egress_filter_rules", egress_filter_rules)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ingress_filter_rules and not isinstance(ingress_filter_rules, list):
            raise TypeError("Expected argument 'ingress_filter_rules' to be a list")
        pulumi.set(__self__, "ingress_filter_rules", ingress_filter_rules)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if traffic_mirror_filter_id and not isinstance(traffic_mirror_filter_id, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if traffic_mirror_filter_name and not isinstance(traffic_mirror_filter_name, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_name' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_name", traffic_mirror_filter_name)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        筛选条件的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        筛选条件实例描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="egressFilterRules")
    def egress_filter_rules(self) -> Sequence['outputs.GetTrafficMirrorFilterEgressFilterRuleResult']:
        """
        出方向筛选规则的详细信息。
        """
        return pulumi.get(self, "egress_filter_rules")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ingressFilterRules")
    def ingress_filter_rules(self) -> Sequence['outputs.GetTrafficMirrorFilterIngressFilterRuleResult']:
        """
        入方向筛选规则的详细信息。
        """
        return pulumi.get(self, "ingress_filter_rules")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        筛选条件所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        筛选条件状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTrafficMirrorFilterTagResult']:
        """
        标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> builtins.str:
        """
        筛选条件实例ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @property
    @pulumi.getter(name="trafficMirrorFilterName")
    def traffic_mirror_filter_name(self) -> builtins.str:
        """
        筛选条件名称。
        """
        return pulumi.get(self, "traffic_mirror_filter_name")


class AwaitableGetTrafficMirrorFilterResult(GetTrafficMirrorFilterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorFilterResult(
            created_time=self.created_time,
            description=self.description,
            egress_filter_rules=self.egress_filter_rules,
            id=self.id,
            ingress_filter_rules=self.ingress_filter_rules,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            traffic_mirror_filter_id=self.traffic_mirror_filter_id,
            traffic_mirror_filter_name=self.traffic_mirror_filter_name)


def get_traffic_mirror_filter(id: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorFilterResult:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorFilter


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getTrafficMirrorFilter:getTrafficMirrorFilter', __args__, opts=opts, typ=GetTrafficMirrorFilterResult).value

    return AwaitableGetTrafficMirrorFilterResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        egress_filter_rules=pulumi.get(__ret__, 'egress_filter_rules'),
        id=pulumi.get(__ret__, 'id'),
        ingress_filter_rules=pulumi.get(__ret__, 'ingress_filter_rules'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        traffic_mirror_filter_id=pulumi.get(__ret__, 'traffic_mirror_filter_id'),
        traffic_mirror_filter_name=pulumi.get(__ret__, 'traffic_mirror_filter_name'))
def get_traffic_mirror_filter_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrafficMirrorFilterResult]:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorFilter


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getTrafficMirrorFilter:getTrafficMirrorFilter', __args__, opts=opts, typ=GetTrafficMirrorFilterResult)
    return __ret__.apply(lambda __response__: GetTrafficMirrorFilterResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        egress_filter_rules=pulumi.get(__response__, 'egress_filter_rules'),
        id=pulumi.get(__response__, 'id'),
        ingress_filter_rules=pulumi.get(__response__, 'ingress_filter_rules'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        traffic_mirror_filter_id=pulumi.get(__response__, 'traffic_mirror_filter_id'),
        traffic_mirror_filter_name=pulumi.get(__response__, 'traffic_mirror_filter_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DbAccountArgs', 'DbAccount']

@pulumi.input_type
class DbAccountArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[builtins.str],
                 account_password: pulumi.Input[builtins.str],
                 account_type: pulumi.Input[builtins.str],
                 account_privileges: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 not_allow_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a DbAccount resource.
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。账号名称的设置规则如下：长度 2~63 个字符。由字母、数字、下划线（*）或中划线（-）组成。以字母开头，字母或数字结尾。不能以 pg* 开头。不能使用保留关键字，所有被禁用的关键词请参见禁用关键词。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。数据库账号密码的设置规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的任意三种组成。特殊字符为 !@#$%^*()&_+-=。
        :param pulumi.Input[builtins.str] account_type: 数据库账号类型，取值范围如下：Super：高权限账号。Normal：普通账号。InstanceReadOnly：实例只读账号。
        :param pulumi.Input[builtins.str] account_privileges: 账号权限信息。多个权限中间以英文逗号（,）分隔。取值：Login：登录权限。Inherit：继承权限。CreateRole：创建角色权限。CreateDB：创建数据库权限。说明当账号类型为高权限账号时，无需传入该参数，默认支持全部权限。当账号类型为普通账号时，支持传入该参数，默认值为 Login 和 Inherit。账号类型为实例只读账号时，即 AccountType 取值为 InstanceReadOnly 时，不支持传入该参数
        :param pulumi.Input[builtins.str] instance_id: 实例 ID
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] not_allow_privileges: 为账号禁用的权限。当前仅支持取值为 DDL。说明仅支持为高权限账号或普通账号传入此字段，即 AccountType 取值为 Super 或 Normal 时。
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "account_password", account_password)
        pulumi.set(__self__, "account_type", account_type)
        if account_privileges is not None:
            pulumi.set(__self__, "account_privileges", account_privileges)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if not_allow_privileges is not None:
            pulumi.set(__self__, "not_allow_privileges", not_allow_privileges)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[builtins.str]:
        """
        数据库账号名称。账号名称的设置规则如下：长度 2~63 个字符。由字母、数字、下划线（*）或中划线（-）组成。以字母开头，字母或数字结尾。不能以 pg* 开头。不能使用保留关键字，所有被禁用的关键词请参见禁用关键词。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Input[builtins.str]:
        """
        数据库账号的密码。数据库账号密码的设置规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的任意三种组成。特殊字符为 !@#$%^*()&_+-=。
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Input[builtins.str]:
        """
        数据库账号类型，取值范围如下：Super：高权限账号。Normal：普通账号。InstanceReadOnly：实例只读账号。
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号权限信息。多个权限中间以英文逗号（,）分隔。取值：Login：登录权限。Inherit：继承权限。CreateRole：创建角色权限。CreateDB：创建数据库权限。说明当账号类型为高权限账号时，无需传入该参数，默认支持全部权限。当账号类型为普通账号时，支持传入该参数，默认值为 Login 和 Inherit。账号类型为实例只读账号时，即 AccountType 取值为 InstanceReadOnly 时，不支持传入该参数
        """
        return pulumi.get(self, "account_privileges")

    @account_privileges.setter
    def account_privileges(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_privileges", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="notAllowPrivileges")
    def not_allow_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        为账号禁用的权限。当前仅支持取值为 DDL。说明仅支持为高权限账号或普通账号传入此字段，即 AccountType 取值为 Super 或 Normal 时。
        """
        return pulumi.get(self, "not_allow_privileges")

    @not_allow_privileges.setter
    def not_allow_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "not_allow_privileges", value)


@pulumi.input_type
class _DbAccountState:
    def __init__(__self__, *,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 not_allow_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering DbAccount resources.
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。账号名称的设置规则如下：长度 2~63 个字符。由字母、数字、下划线（*）或中划线（-）组成。以字母开头，字母或数字结尾。不能以 pg* 开头。不能使用保留关键字，所有被禁用的关键词请参见禁用关键词。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。数据库账号密码的设置规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的任意三种组成。特殊字符为 !@#$%^*()&_+-=。
        :param pulumi.Input[builtins.str] account_privileges: 账号权限信息。多个权限中间以英文逗号（,）分隔。取值：Login：登录权限。Inherit：继承权限。CreateRole：创建角色权限。CreateDB：创建数据库权限。说明当账号类型为高权限账号时，无需传入该参数，默认支持全部权限。当账号类型为普通账号时，支持传入该参数，默认值为 Login 和 Inherit。账号类型为实例只读账号时，即 AccountType 取值为 InstanceReadOnly 时，不支持传入该参数
        :param pulumi.Input[builtins.str] account_type: 数据库账号类型，取值范围如下：Super：高权限账号。Normal：普通账号。InstanceReadOnly：实例只读账号。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] not_allow_privileges: 为账号禁用的权限。当前仅支持取值为 DDL。说明仅支持为高权限账号或普通账号传入此字段，即 AccountType 取值为 Super 或 Normal 时。
        """
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if account_password is not None:
            pulumi.set(__self__, "account_password", account_password)
        if account_privileges is not None:
            pulumi.set(__self__, "account_privileges", account_privileges)
        if account_type is not None:
            pulumi.set(__self__, "account_type", account_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if not_allow_privileges is not None:
            pulumi.set(__self__, "not_allow_privileges", not_allow_privileges)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库账号名称。账号名称的设置规则如下：长度 2~63 个字符。由字母、数字、下划线（*）或中划线（-）组成。以字母开头，字母或数字结尾。不能以 pg* 开头。不能使用保留关键字，所有被禁用的关键词请参见禁用关键词。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库账号的密码。数据库账号密码的设置规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的任意三种组成。特殊字符为 !@#$%^*()&_+-=。
        """
        return pulumi.get(self, "account_password")

    @account_password.setter
    def account_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_password", value)

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号权限信息。多个权限中间以英文逗号（,）分隔。取值：Login：登录权限。Inherit：继承权限。CreateRole：创建角色权限。CreateDB：创建数据库权限。说明当账号类型为高权限账号时，无需传入该参数，默认支持全部权限。当账号类型为普通账号时，支持传入该参数，默认值为 Login 和 Inherit。账号类型为实例只读账号时，即 AccountType 取值为 InstanceReadOnly 时，不支持传入该参数
        """
        return pulumi.get(self, "account_privileges")

    @account_privileges.setter
    def account_privileges(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_privileges", value)

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        数据库账号类型，取值范围如下：Super：高权限账号。Normal：普通账号。InstanceReadOnly：实例只读账号。
        """
        return pulumi.get(self, "account_type")

    @account_type.setter
    def account_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="notAllowPrivileges")
    def not_allow_privileges(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        为账号禁用的权限。当前仅支持取值为 DDL。说明仅支持为高权限账号或普通账号传入此字段，即 AccountType 取值为 Super 或 Normal 时。
        """
        return pulumi.get(self, "not_allow_privileges")

    @not_allow_privileges.setter
    def not_allow_privileges(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "not_allow_privileges", value)


@pulumi.type_token("bytepluscc:rdspostgresql/dbAccount:DbAccount")
class DbAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 not_allow_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        RDS PostgreSQL 数据库账号

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        r_ds_postgre_sqldb_account_normal_demo = bytepluscc.rdspostgresql.DbAccount("RDSPostgreSQLDBAccountNormalDemo",
            instance_id="postgres-xxxxxxx",
            account_name="ccapi-test-Normal",
            account_password="**********",
            account_type="Normal",
            account_privileges="Inherit,Login,CreateRole,CreateDB",
            not_allow_privileges=["DDL"])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdspostgresql/dbAccount:DbAccount example "instance_id|account_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。账号名称的设置规则如下：长度 2~63 个字符。由字母、数字、下划线（*）或中划线（-）组成。以字母开头，字母或数字结尾。不能以 pg* 开头。不能使用保留关键字，所有被禁用的关键词请参见禁用关键词。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。数据库账号密码的设置规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的任意三种组成。特殊字符为 !@#$%^*()&_+-=。
        :param pulumi.Input[builtins.str] account_privileges: 账号权限信息。多个权限中间以英文逗号（,）分隔。取值：Login：登录权限。Inherit：继承权限。CreateRole：创建角色权限。CreateDB：创建数据库权限。说明当账号类型为高权限账号时，无需传入该参数，默认支持全部权限。当账号类型为普通账号时，支持传入该参数，默认值为 Login 和 Inherit。账号类型为实例只读账号时，即 AccountType 取值为 InstanceReadOnly 时，不支持传入该参数
        :param pulumi.Input[builtins.str] account_type: 数据库账号类型，取值范围如下：Super：高权限账号。Normal：普通账号。InstanceReadOnly：实例只读账号。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] not_allow_privileges: 为账号禁用的权限。当前仅支持取值为 DDL。说明仅支持为高权限账号或普通账号传入此字段，即 AccountType 取值为 Super 或 Normal 时。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DbAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        RDS PostgreSQL 数据库账号

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        r_ds_postgre_sqldb_account_normal_demo = bytepluscc.rdspostgresql.DbAccount("RDSPostgreSQLDBAccountNormalDemo",
            instance_id="postgres-xxxxxxx",
            account_name="ccapi-test-Normal",
            account_password="**********",
            account_type="Normal",
            account_privileges="Inherit,Login,CreateRole,CreateDB",
            not_allow_privileges=["DDL"])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdspostgresql/dbAccount:DbAccount example "instance_id|account_name"
        ```

        :param str resource_name: The name of the resource.
        :param DbAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DbAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_password: Optional[pulumi.Input[builtins.str]] = None,
                 account_privileges: Optional[pulumi.Input[builtins.str]] = None,
                 account_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 not_allow_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DbAccountArgs.__new__(DbAccountArgs)

            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            if account_password is None and not opts.urn:
                raise TypeError("Missing required property 'account_password'")
            __props__.__dict__["account_password"] = account_password
            __props__.__dict__["account_privileges"] = account_privileges
            if account_type is None and not opts.urn:
                raise TypeError("Missing required property 'account_type'")
            __props__.__dict__["account_type"] = account_type
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["not_allow_privileges"] = not_allow_privileges
        super(DbAccount, __self__).__init__(
            'bytepluscc:rdspostgresql/dbAccount:DbAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_name: Optional[pulumi.Input[builtins.str]] = None,
            account_password: Optional[pulumi.Input[builtins.str]] = None,
            account_privileges: Optional[pulumi.Input[builtins.str]] = None,
            account_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            not_allow_privileges: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'DbAccount':
        """
        Get an existing DbAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_name: 数据库账号名称。账号名称的设置规则如下：长度 2~63 个字符。由字母、数字、下划线（*）或中划线（-）组成。以字母开头，字母或数字结尾。不能以 pg* 开头。不能使用保留关键字，所有被禁用的关键词请参见禁用关键词。
        :param pulumi.Input[builtins.str] account_password: 数据库账号的密码。数据库账号密码的设置规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的任意三种组成。特殊字符为 !@#$%^*()&_+-=。
        :param pulumi.Input[builtins.str] account_privileges: 账号权限信息。多个权限中间以英文逗号（,）分隔。取值：Login：登录权限。Inherit：继承权限。CreateRole：创建角色权限。CreateDB：创建数据库权限。说明当账号类型为高权限账号时，无需传入该参数，默认支持全部权限。当账号类型为普通账号时，支持传入该参数，默认值为 Login 和 Inherit。账号类型为实例只读账号时，即 AccountType 取值为 InstanceReadOnly 时，不支持传入该参数
        :param pulumi.Input[builtins.str] account_type: 数据库账号类型，取值范围如下：Super：高权限账号。Normal：普通账号。InstanceReadOnly：实例只读账号。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] not_allow_privileges: 为账号禁用的权限。当前仅支持取值为 DDL。说明仅支持为高权限账号或普通账号传入此字段，即 AccountType 取值为 Super 或 Normal 时。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DbAccountState.__new__(_DbAccountState)

        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["account_password"] = account_password
        __props__.__dict__["account_privileges"] = account_privileges
        __props__.__dict__["account_type"] = account_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["not_allow_privileges"] = not_allow_privileges
        return DbAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[builtins.str]:
        """
        数据库账号名称。账号名称的设置规则如下：长度 2~63 个字符。由字母、数字、下划线（*）或中划线（-）组成。以字母开头，字母或数字结尾。不能以 pg* 开头。不能使用保留关键字，所有被禁用的关键词请参见禁用关键词。
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountPassword")
    def account_password(self) -> pulumi.Output[builtins.str]:
        """
        数据库账号的密码。数据库账号密码的设置规则如下：长度为 8~32 个字符。由大写字母、小写字母、数字、特殊字符中的任意三种组成。特殊字符为 !@#$%^*()&_+-=。
        """
        return pulumi.get(self, "account_password")

    @property
    @pulumi.getter(name="accountPrivileges")
    def account_privileges(self) -> pulumi.Output[builtins.str]:
        """
        账号权限信息。多个权限中间以英文逗号（,）分隔。取值：Login：登录权限。Inherit：继承权限。CreateRole：创建角色权限。CreateDB：创建数据库权限。说明当账号类型为高权限账号时，无需传入该参数，默认支持全部权限。当账号类型为普通账号时，支持传入该参数，默认值为 Login 和 Inherit。账号类型为实例只读账号时，即 AccountType 取值为 InstanceReadOnly 时，不支持传入该参数
        """
        return pulumi.get(self, "account_privileges")

    @property
    @pulumi.getter(name="accountType")
    def account_type(self) -> pulumi.Output[builtins.str]:
        """
        数据库账号类型，取值范围如下：Super：高权限账号。Normal：普通账号。InstanceReadOnly：实例只读账号。
        """
        return pulumi.get(self, "account_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="notAllowPrivileges")
    def not_allow_privileges(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        为账号禁用的权限。当前仅支持取值为 DDL。说明仅支持为高权限账号或普通账号传入此字段，即 AccountType 取值为 Super 或 Normal 时。
        """
        return pulumi.get(self, "not_allow_privileges")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CustomerGatewayArgs', 'CustomerGateway']

@pulumi.input_type
class CustomerGatewayArgs:
    def __init__(__self__, *,
                 ip_address: pulumi.Input[builtins.str],
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 customer_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CustomerGatewayTagArgs']]]] = None):
        """
        The set of arguments for constructing a CustomerGateway resource.
        :param pulumi.Input[builtins.str] ip_address: 对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        :param pulumi.Input[builtins.int] asn: 用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        :param pulumi.Input[builtins.str] customer_gateway_name: 用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        :param pulumi.Input[builtins.str] description: 用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        :param pulumi.Input[builtins.str] project_name: 用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        """
        pulumi.set(__self__, "ip_address", ip_address)
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if customer_gateway_name is not None:
            pulumi.set(__self__, "customer_gateway_name", customer_gateway_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Input[builtins.str]:
        """
        对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "asn", value)

    @property
    @pulumi.getter(name="customerGatewayName")
    def customer_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        """
        return pulumi.get(self, "customer_gateway_name")

    @customer_gateway_name.setter
    def customer_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customer_gateway_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomerGatewayTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomerGatewayTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _CustomerGatewayState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 connection_count: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 customer_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 customer_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CustomerGatewayTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomerGateway resources.
        :param pulumi.Input[builtins.str] account_id: 用户网关所属账户的ID。
        :param pulumi.Input[builtins.int] asn: 用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        :param pulumi.Input[builtins.int] connection_count: 用户网关关联的IPsec连接的数量。
        :param pulumi.Input[builtins.str] created_time: 创建用户网关的时间。
        :param pulumi.Input[builtins.str] customer_gateway_id: 网关ID。
        :param pulumi.Input[builtins.str] customer_gateway_name: 用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        :param pulumi.Input[builtins.str] description: 用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] ip_address: 对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        :param pulumi.Input[builtins.str] project_name: 用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        :param pulumi.Input[builtins.str] status: 用户网关的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        :param pulumi.Input[builtins.str] updated_time: 更新用户网关的时间。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if connection_count is not None:
            pulumi.set(__self__, "connection_count", connection_count)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if customer_gateway_id is not None:
            pulumi.set(__self__, "customer_gateway_id", customer_gateway_id)
        if customer_gateway_name is not None:
            pulumi.set(__self__, "customer_gateway_name", customer_gateway_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关所属账户的ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "asn", value)

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        用户网关关联的IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @connection_count.setter
    def connection_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connection_count", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建用户网关的时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关ID。
        """
        return pulumi.get(self, "customer_gateway_id")

    @customer_gateway_id.setter
    def customer_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customer_gateway_id", value)

    @property
    @pulumi.getter(name="customerGatewayName")
    def customer_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        """
        return pulumi.get(self, "customer_gateway_name")

    @customer_gateway_name.setter
    def customer_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customer_gateway_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户网关的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomerGatewayTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomerGatewayTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新用户网关的时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vpn/customerGateway:CustomerGateway")
class CustomerGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 customer_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomerGatewayTagArgs', 'CustomerGatewayTagArgsDict']]]]] = None,
                 __props__=None):
        """
        用户网关是您本地网关侧的信息集合和抽象。通过用户网关，您可以把本地网关的信息注册到云上VPC之中。一个用户网关，可以对接多个VPN网关。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vpncustomergateway_demo = bytepluscc.vpn.CustomerGateway("vpncustomergatewayDemo",
            asn=64513,
            customer_gateway_name="ccapi-test",
            description="testdesc",
            ip_address="115.***.151.5",
            ip_version="ipv4",
            project_name="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpn/customerGateway:CustomerGateway example "customer_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] asn: 用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        :param pulumi.Input[builtins.str] customer_gateway_name: 用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        :param pulumi.Input[builtins.str] description: 用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] ip_address: 对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        :param pulumi.Input[builtins.str] project_name: 用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomerGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        用户网关是您本地网关侧的信息集合和抽象。通过用户网关，您可以把本地网关的信息注册到云上VPC之中。一个用户网关，可以对接多个VPN网关。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vpncustomergateway_demo = bytepluscc.vpn.CustomerGateway("vpncustomergatewayDemo",
            asn=64513,
            customer_gateway_name="ccapi-test",
            description="testdesc",
            ip_address="115.***.151.5",
            ip_version="ipv4",
            project_name="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpn/customerGateway:CustomerGateway example "customer_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param CustomerGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomerGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 customer_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomerGatewayTagArgs', 'CustomerGatewayTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomerGatewayArgs.__new__(CustomerGatewayArgs)

            __props__.__dict__["asn"] = asn
            __props__.__dict__["customer_gateway_name"] = customer_gateway_name
            __props__.__dict__["description"] = description
            if ip_address is None and not opts.urn:
                raise TypeError("Missing required property 'ip_address'")
            __props__.__dict__["ip_address"] = ip_address
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["account_id"] = None
            __props__.__dict__["connection_count"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["customer_gateway_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(CustomerGateway, __self__).__init__(
            'bytepluscc:vpn/customerGateway:CustomerGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            asn: Optional[pulumi.Input[builtins.int]] = None,
            connection_count: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            customer_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            customer_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ip_address: Optional[pulumi.Input[builtins.str]] = None,
            ip_version: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomerGatewayTagArgs', 'CustomerGatewayTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'CustomerGateway':
        """
        Get an existing CustomerGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: 用户网关所属账户的ID。
        :param pulumi.Input[builtins.int] asn: 用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        :param pulumi.Input[builtins.int] connection_count: 用户网关关联的IPsec连接的数量。
        :param pulumi.Input[builtins.str] created_time: 创建用户网关的时间。
        :param pulumi.Input[builtins.str] customer_gateway_id: 网关ID。
        :param pulumi.Input[builtins.str] customer_gateway_name: 用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        :param pulumi.Input[builtins.str] description: 用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] ip_address: 对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        :param pulumi.Input[builtins.str] project_name: 用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        :param pulumi.Input[builtins.str] status: 用户网关的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        :param pulumi.Input[builtins.str] updated_time: 更新用户网关的时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomerGatewayState.__new__(_CustomerGatewayState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["asn"] = asn
        __props__.__dict__["connection_count"] = connection_count
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["customer_gateway_id"] = customer_gateway_id
        __props__.__dict__["customer_gateway_name"] = customer_gateway_name
        __props__.__dict__["description"] = description
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return CustomerGateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        用户网关所属账户的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def asn(self) -> pulumi.Output[builtins.int]:
        """
        用户网关的ASN（Autonomous System Number）。如需使用BGP功能，则此参数必须填写。ASN有效范围1～4294967295（137718 、150436、65533除外）。
        """
        return pulumi.get(self, "asn")

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> pulumi.Output[builtins.int]:
        """
        用户网关关联的IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建用户网关的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customerGatewayId")
    def customer_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        网关ID。
        """
        return pulumi.get(self, "customer_gateway_id")

    @property
    @pulumi.getter(name="customerGatewayName")
    def customer_gateway_name(self) -> pulumi.Output[builtins.str]:
        """
        用户网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短划线（-）。长度限制为1 ~ 128个字符。不填默认为用户网关的ID。
        """
        return pulumi.get(self, "customer_gateway_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        用户网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[builtins.str]:
        """
        对端本地数据中心网关的静态公网IP地址或其他VPC的VPN网关出口IP地址。若对端为非固定静态公网IP，此处需传入0.0.0.0。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的IP地址协议类型，取值如下：ipv4 （默认值）ipv6
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        用户网关所属的项目。不填默认为default，即创建的资源属于default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        用户网关的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.CustomerGatewayTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新用户网关的时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PermissionSetArgs', 'PermissionSet']

@pulumi.input_type
class PermissionSetArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 permission_policies: Optional[pulumi.Input[Sequence[pulumi.Input['PermissionSetPermissionPolicyArgs']]]] = None,
                 relay_state: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a PermissionSet resource.
        :param pulumi.Input[builtins.str] name: 权限集名称。
        :param pulumi.Input[builtins.str] description: 权限集描述。
        :param pulumi.Input[builtins.str] relay_state: 跳转控制台 URL。
        :param pulumi.Input[builtins.int] session_duration: session 过期时间，单位秒。
        """
        pulumi.set(__self__, "name", name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if permission_policies is not None:
            pulumi.set(__self__, "permission_policies", permission_policies)
        if relay_state is not None:
            pulumi.set(__self__, "relay_state", relay_state)
        if session_duration is not None:
            pulumi.set(__self__, "session_duration", session_duration)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        权限集名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限集描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="permissionPolicies")
    def permission_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PermissionSetPermissionPolicyArgs']]]]:
        return pulumi.get(self, "permission_policies")

    @permission_policies.setter
    def permission_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PermissionSetPermissionPolicyArgs']]]]):
        pulumi.set(self, "permission_policies", value)

    @property
    @pulumi.getter(name="relayState")
    def relay_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        跳转控制台 URL。
        """
        return pulumi.get(self, "relay_state")

    @relay_state.setter
    def relay_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "relay_state", value)

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        session 过期时间，单位秒。
        """
        return pulumi.get(self, "session_duration")

    @session_duration.setter
    def session_duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "session_duration", value)


@pulumi.input_type
class _PermissionSetState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_policies: Optional[pulumi.Input[Sequence[pulumi.Input['PermissionSetPermissionPolicyArgs']]]] = None,
                 permission_set_id: Optional[pulumi.Input[builtins.str]] = None,
                 relay_state: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 status_notifications: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering PermissionSet resources.
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 权限集描述。
        :param pulumi.Input[builtins.str] name: 权限集名称。
        :param pulumi.Input[builtins.str] permission_set_id: 权限集 ID。
        :param pulumi.Input[builtins.str] relay_state: 跳转控制台 URL。
        :param pulumi.Input[builtins.int] session_duration: session 过期时间，单位秒。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] status_notifications: 状态通知配置。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if permission_policies is not None:
            pulumi.set(__self__, "permission_policies", permission_policies)
        if permission_set_id is not None:
            pulumi.set(__self__, "permission_set_id", permission_set_id)
        if relay_state is not None:
            pulumi.set(__self__, "relay_state", relay_state)
        if session_duration is not None:
            pulumi.set(__self__, "session_duration", session_duration)
        if status_notifications is not None:
            pulumi.set(__self__, "status_notifications", status_notifications)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限集描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限集名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="permissionPolicies")
    def permission_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PermissionSetPermissionPolicyArgs']]]]:
        return pulumi.get(self, "permission_policies")

    @permission_policies.setter
    def permission_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PermissionSetPermissionPolicyArgs']]]]):
        pulumi.set(self, "permission_policies", value)

    @property
    @pulumi.getter(name="permissionSetId")
    def permission_set_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限集 ID。
        """
        return pulumi.get(self, "permission_set_id")

    @permission_set_id.setter
    def permission_set_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_set_id", value)

    @property
    @pulumi.getter(name="relayState")
    def relay_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        跳转控制台 URL。
        """
        return pulumi.get(self, "relay_state")

    @relay_state.setter
    def relay_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "relay_state", value)

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        session 过期时间，单位秒。
        """
        return pulumi.get(self, "session_duration")

    @session_duration.setter
    def session_duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "session_duration", value)

    @property
    @pulumi.getter(name="statusNotifications")
    def status_notifications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        状态通知配置。
        """
        return pulumi.get(self, "status_notifications")

    @status_notifications.setter
    def status_notifications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "status_notifications", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:cloudidentity/permissionSet:PermissionSet")
class PermissionSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PermissionSetPermissionPolicyArgs', 'PermissionSetPermissionPolicyArgsDict']]]]] = None,
                 relay_state: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        当您创建好云身份中心用户后，需要授予用户访问到各账号的登录访问权限。当用户访问火山引擎云资源的权限访问具备可抽象的共性时，如：网络运维权限、安全管理权限等，您可以在云身份中心预置访问权限集作为权限模版，最终基于访问权限集来实现中心化授权。云身份中心将会为您同步分发访问权限集到各个账号，减少企业权限的运维成本。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cloudidentity/permissionSet:PermissionSet example "permission_set_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 权限集描述。
        :param pulumi.Input[builtins.str] name: 权限集名称。
        :param pulumi.Input[builtins.str] relay_state: 跳转控制台 URL。
        :param pulumi.Input[builtins.int] session_duration: session 过期时间，单位秒。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PermissionSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        当您创建好云身份中心用户后，需要授予用户访问到各账号的登录访问权限。当用户访问火山引擎云资源的权限访问具备可抽象的共性时，如：网络运维权限、安全管理权限等，您可以在云身份中心预置访问权限集作为权限模版，最终基于访问权限集来实现中心化授权。云身份中心将会为您同步分发访问权限集到各个账号，减少企业权限的运维成本。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cloudidentity/permissionSet:PermissionSet example "permission_set_id"
        ```

        :param str resource_name: The name of the resource.
        :param PermissionSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PermissionSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PermissionSetPermissionPolicyArgs', 'PermissionSetPermissionPolicyArgsDict']]]]] = None,
                 relay_state: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PermissionSetArgs.__new__(PermissionSetArgs)

            __props__.__dict__["description"] = description
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["permission_policies"] = permission_policies
            __props__.__dict__["relay_state"] = relay_state
            __props__.__dict__["session_duration"] = session_duration
            __props__.__dict__["created_time"] = None
            __props__.__dict__["permission_set_id"] = None
            __props__.__dict__["status_notifications"] = None
            __props__.__dict__["updated_time"] = None
        super(PermissionSet, __self__).__init__(
            'bytepluscc:cloudidentity/permissionSet:PermissionSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            permission_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PermissionSetPermissionPolicyArgs', 'PermissionSetPermissionPolicyArgsDict']]]]] = None,
            permission_set_id: Optional[pulumi.Input[builtins.str]] = None,
            relay_state: Optional[pulumi.Input[builtins.str]] = None,
            session_duration: Optional[pulumi.Input[builtins.int]] = None,
            status_notifications: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'PermissionSet':
        """
        Get an existing PermissionSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 权限集描述。
        :param pulumi.Input[builtins.str] name: 权限集名称。
        :param pulumi.Input[builtins.str] permission_set_id: 权限集 ID。
        :param pulumi.Input[builtins.str] relay_state: 跳转控制台 URL。
        :param pulumi.Input[builtins.int] session_duration: session 过期时间，单位秒。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] status_notifications: 状态通知配置。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PermissionSetState.__new__(_PermissionSetState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["permission_policies"] = permission_policies
        __props__.__dict__["permission_set_id"] = permission_set_id
        __props__.__dict__["relay_state"] = relay_state
        __props__.__dict__["session_duration"] = session_duration
        __props__.__dict__["status_notifications"] = status_notifications
        __props__.__dict__["updated_time"] = updated_time
        return PermissionSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        权限集描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        权限集名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="permissionPolicies")
    def permission_policies(self) -> pulumi.Output[Sequence['outputs.PermissionSetPermissionPolicy']]:
        return pulumi.get(self, "permission_policies")

    @property
    @pulumi.getter(name="permissionSetId")
    def permission_set_id(self) -> pulumi.Output[builtins.str]:
        """
        权限集 ID。
        """
        return pulumi.get(self, "permission_set_id")

    @property
    @pulumi.getter(name="relayState")
    def relay_state(self) -> pulumi.Output[builtins.str]:
        """
        跳转控制台 URL。
        """
        return pulumi.get(self, "relay_state")

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> pulumi.Output[builtins.int]:
        """
        session 过期时间，单位秒。
        """
        return pulumi.get(self, "session_duration")

    @property
    @pulumi.getter(name="statusNotifications")
    def status_notifications(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        状态通知配置。
        """
        return pulumi.get(self, "status_notifications")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .addon import *
from .cluster import *
from .default_node_pool import *
from .get_addon import *
from .get_addons import *
from .get_cluster import *
from .get_clusters import *
from .get_default_node_pool import *
from .get_default_node_pools import *
from .get_node import *
from .get_node_pool import *
from .get_node_pools import *
from .get_nodes import *
from .get_permission import *
from .get_permissions import *
from .node import *
from .node_pool import *
from .permission import *
from ._inputs import *
from . import outputs
